@@ -122,6 +122,10 @@ define('wildcard', group=CocaineGroup,
        help='wildcard', default='*',
        type=str)
 
+define('environment', group=CocaineGroup,
+       help='specify environment', default="",
+       type=str)
+
 # CocaineGroup
 define('host', group=CocaineGroup,
        help='Host of buildfarm locator',
@@ -169,6 +173,7 @@ def gen_task(task):
 def upload():
     task = {"appname": options.appname,
             "version": options.version,
+            "environment": options.environment,
             "url": options.url,
             "manifest": options.manifest}
 
@@ -184,6 +189,7 @@ def upload():
 @jail
 def start():
     task = {"appname": options.appname,
+            "environment": options.environment,
             "version": options.version}
     if options.profile:
         task["profilename"] = options.profile
@@ -200,6 +206,7 @@ def start():
 @jail
 def stop():
     task = {"appname": options.appname,
+            "environment": options.environment,
             "version": options.version}
 
     task = gen_task(task)
@@ -220,6 +227,7 @@ def deploy():
     task = {"appname": options.appname,
             "version": options.version,
             "profilename": options.profile,
+            "environment": options.environment,
             "weight": options.weight}
 
     task = gen_task(task)
@@ -236,6 +244,7 @@ def undeploy():
     log.info("Application %s would be undeployed with profile.",
              options.appname)
     task = {"appname": options.appname,
+            "environment": options.environment,
             "version": options.version}
 
     task = gen_task(task)
@@ -252,6 +261,7 @@ def remove():
     log.info("Application %s would be undeployed with profile.",
              options.appname)
     task = {"appname": options.appname,
+            "environment": options.environment,
             "version": options.version}
 
     task = gen_task(task)
@@ -267,7 +277,9 @@ def remove():
 def listing():
     log.info("Fetching a list of your applications according to wildcard %s",
              options.wildcard)
-    task = {}
+    task = {
+        "environment": options.environment
+    }
     if options.wildcard:
         task["wildcard"] = options.wildcard
 
